@@ -18,7 +18,7 @@ pub fn fragment_type(len: usize) -> usize {
     let mut result = 0;
     for ft in 0..NFT {
         let t = total(len, ft);
-        if t < best {
+        if t <= best {
             best = t;
             result = ft;
         }
@@ -47,6 +47,11 @@ impl ByteStorage {
         }
     }
 
+    pub fn repack_file(&self, db: &DB) -> i64 {
+        let r = Fragment::new(0, self.bpf);
+        self.file.repack(db, &r)
+    }
+
     pub fn get_id(&self, db: &DB) -> u64 {
         let mut result = self.id_gen.get();
         if result == u64::MAX {
