@@ -4,13 +4,13 @@ use crate::*;
 /// When stored in a database record, binary(n) and string(n) values are allocated (n+1) bytes (8<=n<=249).
 /// If the value is more than n bytes, the length and the first (n-8) bytes are stored inline, and the rest are coded.
 
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy)]
 pub struct Code {
     pub id: u64,
     pub ft: usize,
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub enum Value {
     None,
     RcBinary(Rc<Vec<u8>>),
